@@ -227,6 +227,7 @@ def clean_ini(path, section, parameter):
 
     # read file to parser
     config = bleachbit.RawConfigParser()
+    config.optionxform = lambda option: option
     config.write = write
     with open(path, 'r', encoding=encoding) as fp:
         config.read_file(fp)
@@ -258,7 +259,7 @@ def clean_json(path, target):
     targets = target.split('/')
 
     # read file to parser
-    with open(path, 'r') as f:
+    with open(path, 'r', encoding='utf-8') as f:
         js = json.load(f)
 
     # change file
@@ -286,7 +287,7 @@ def clean_json(path, target):
         if options.get('shred'):
             delete(path, True)
         # write file
-        with open(path, 'w') as f:
+        with open(path, 'w', encoding='utf-8') as f:
             json.dump(js, f)
 
 
@@ -675,9 +676,13 @@ def sync():
 
 def truncate_f(f):
     """Truncate the file object"""
-    f.truncate(0)
-    f.flush()
-    os.fsync(f.fileno())
+    try:
+        f.truncate(0)
+        f.flush()
+        os.fsync(f.fileno())
+    except OSError as e:
+        if e.errno != errno.ENOSPC:
+            raise
 
 
 def uris_to_paths(file_uris):
@@ -858,7 +863,7 @@ def wipe_path(pathname, idle=False):
     def temporaryfile():
         # reference
         # http://en.wikipedia.org/wiki/Comparison_of_file_systems#Limits
-        maxlen = 245
+        maxlen = 185
         f = None
         while True:
             try:
@@ -870,11 +875,12 @@ def wipe_path(pathname, idle=False):
                     delete, f.name, allow_shred=False, ignore_missing=True)
                 break
             except OSError as e:
-                if e.errno in (errno.ENAMETOOLONG, errno.ENOSPC, errno.ENOENT):
+                if e.errno in (errno.ENAMETOOLONG, errno.ENOSPC, errno.ENOENT, errno.EINVAL):
                     # ext3 on Linux 3.5 returns ENOSPC if the full path is greater than 264.
                     # Shrinking the size helps.
 
                     # Microsoft Windows returns ENOENT "No such file or directory"
+                    # or EINVAL "Invalid argument"
                     # when the path is too long such as %TEMP% but not in C:\
                     if maxlen > 5:
                         maxlen -= 5
@@ -927,7 +933,7 @@ def wipe_path(pathname, idle=False):
                 if e.errno == errno.ENOSPC:
                     if len(blanks) > 1:
                         # Try writing smaller blocks
-                        blanks = blanks[0:int(len(blanks) / 2)]
+                        blanks = blanks[0:len(blanks) // 2]
                     else:
                         break
                 elif e.errno == errno.EFBIG:
@@ -957,7 +963,7 @@ def wipe_path(pathname, idle=False):
         total_bytes += f.tell()
         # If no bytes were written, then quit.
         # See https://github.com/bleachbit/bleachbit/issues/502
-        if f.tell() < 2:
+        if len(blanks) < 2:
             break
     # sync to disk
     sync()
